@@ -36,31 +36,27 @@ static af_array rgb2gray(const af_array& in, const float r, const float g, const
     Array<cType> gCnst = createValueArray<cType>(matDims, scalar<cType>(g));
     Array<cType> bCnst = createValueArray<cType>(matDims, scalar<cType>(b));
 
+    std::vector<af_seq> slice1(4, af_span), slice2(4, af_span), slice3(4, af_span);
     // extract three channels as three slices
-    af_seq slice1[4] = { af_span, af_span, {0, 0, 1}, af_span };
-    af_seq slice2[4] = { af_span, af_span, {1, 1, 1}, af_span };
-    af_seq slice3[4] = { af_span, af_span, {2, 2, 1}, af_span };
+    slice1[2] = {0, 0, 1};
+    slice2[2] = {1, 1, 1};
+    slice3[2] = {2, 2, 1};
 
-    af_array ch1Temp=0, ch2Temp=0, ch3Temp=0;
-    AF_CHECK(af_index(&ch1Temp, in, 4, slice1));
-    AF_CHECK(af_index(&ch2Temp, in, 4, slice2));
-    AF_CHECK(af_index(&ch3Temp, in, 4, slice3));
+    Array<cType> ch1Temp = createSubArray(input, slice1);
+    Array<cType> ch2Temp = createSubArray(input, slice2);
+    Array<cType> ch3Temp = createSubArray(input, slice3);
 
     // r*Slice0
-    Array<cType> expr1 = arithOp<cType, af_mul_t>(getArray<cType>(ch1Temp), rCnst, matDims);
+    Array<cType> expr1 = arithOp<cType, af_mul_t>(ch1Temp, rCnst, matDims);
     //g*Slice1
-    Array<cType> expr2 = arithOp<cType, af_mul_t>(getArray<cType>(ch2Temp), gCnst, matDims);
+    Array<cType> expr2 = arithOp<cType, af_mul_t>(ch2Temp, gCnst, matDims);
     //b*Slice2
-    Array<cType> expr3 = arithOp<cType, af_mul_t>(getArray<cType>(ch3Temp), bCnst, matDims);
+    Array<cType> expr3 = arithOp<cType, af_mul_t>(ch3Temp, bCnst, matDims);
     //r*Slice0 + g*Slice1
     Array<cType> expr4 = arithOp<cType, af_add_t>(expr1, expr2, matDims);
     //r*Slice0 + g*Slice1 + b*Slice2
     Array<cType> result= arithOp<cType, af_add_t>(expr3, expr4, matDims);
 
-    AF_CHECK(af_release_array(ch1Temp));
-    AF_CHECK(af_release_array(ch2Temp));
-    AF_CHECK(af_release_array(ch3Temp));
-
     return getHandle<cType>(result);
 }
 
