@@ -28,6 +28,10 @@ INSTANTIATE_CORRCOEF(int);
 INSTANTIATE_CORRCOEF(unsigned int);
 INSTANTIATE_CORRCOEF(char);
 INSTANTIATE_CORRCOEF(unsigned char);
+INSTANTIATE_CORRCOEF(intl);
+INSTANTIATE_CORRCOEF(uintl);
+INSTANTIATE_CORRCOEF(short);
+INSTANTIATE_CORRCOEF(unsigned short);
 
 #undef INSTANTIATE_CORRCOEF
 
