@@ -42,11 +42,32 @@ namespace af
         return result;
     }
 
+    int getDeviceId(const array &in)
+    {
+        int device = getDevice();;
+        AF_THROW(af_get_device_id(&device, in.get()));
+        return device;
+    }
+
+    af::Backend getActiveBackend()
+    {
+        af::Backend result = (af::Backend)0;
+        AF_THROW(af_get_active_backend(&result));
+        return result;
+    }
+
     void info()
     {
         AF_THROW(af_info());
     }
 
+    const char* infoString(const bool verbose)
+    {
+        char *str = NULL;
+        AF_THROW(af_info_string(&str, verbose));
+        return (const char *)str;
+    }
+
     void deviceprop(char* d_name, char* d_platform, char *d_toolkit, char* d_compute)
     {
         deviceInfo(d_name, d_platform, d_toolkit, d_compute);
@@ -140,6 +161,23 @@ namespace af
         AF_THROW(af_free_pinned((void *)ptr));
     }
 
+    void *allocHost(const size_t elements, const af::dtype type)
+    {
+        void *ptr;
+        AF_THROW(af_alloc_host(&ptr, elements * size_of(type)));
+        return ptr;
+    }
+
+    void freeHost(const void *ptr)
+    {
+        AF_THROW(af_free_host((void *)ptr));
+    }
+
+    void printMemInfo(const char *msg, const int device_id)
+    {
+        AF_THROW(af_print_mem_info(msg, device_id));
+    }
+
     void deviceGC()
     {
         AF_THROW(af_device_gc());
@@ -164,16 +202,21 @@ namespace af
         return size_bytes;
     }
 
-#define INSTANTIATE(T)                                                  \
-    template<> AFAPI                                                    \
-    T* alloc(const size_t elements)                                     \
-    {                                                                   \
-        return (T*)alloc(elements, (af::dtype)dtype_traits<T>::af_type); \
-    }                                                                   \
-    template<> AFAPI                                                    \
-    T* pinned(const size_t elements)                                    \
-    {                                                                   \
-        return (T*)pinned(elements, (af::dtype)dtype_traits<T>::af_type); \
+#define INSTANTIATE(T)                                                      \
+    template<> AFAPI                                                        \
+    T* alloc(const size_t elements)                                         \
+    {                                                                       \
+        return (T*)alloc(elements, (af::dtype)dtype_traits<T>::af_type);    \
+    }                                                                       \
+    template<> AFAPI                                                        \
+    T* pinned(const size_t elements)                                        \
+    {                                                                       \
+        return (T*)pinned(elements, (af::dtype)dtype_traits<T>::af_type);   \
+    }                                                                       \
+    template<> AFAPI                                                        \
+    T* allocHost(const size_t elements)                                     \
+    {                                                                       \
+        return (T*)allocHost(elements, (af::dtype)dtype_traits<T>::af_type);\
     }
 
     INSTANTIATE(float)
