@@ -10,17 +10,18 @@
 #include <af/defines.h>
 #include <af/blas.h>
 #include <Array.hpp>
+#include <types.hpp>
 
-#ifdef __APPLE__
-#include <Accelerate/Accelerate.h>
-#else
 #ifdef USE_MKL
-#include <mkl_cblas.h>
+    #include <mkl_cblas.h>
 #else
-extern "C" {
-#include <cblas.h>
-}
-#endif
+    #ifdef __APPLE__
+        #include <Accelerate/Accelerate.h>
+    #else
+        extern "C" {
+            #include <cblas.h>
+        }
+    #endif
 #endif
 
 // TODO: Ask upstream for a more official way to detect it
