@@ -14,5 +14,5 @@ namespace cpu
 {
     template<typename T>
     Array<T> transform(const Array<T> &in, const Array<float> &tf, const af::dim4 &odims,
-                        const af_interp_type method, const bool inverse);
+                        const af_interp_type method, const bool inverse, const bool perspective);
 }
