@@ -44,7 +44,11 @@ SPECIALIZE(cdouble)
 SPECIALIZE(char)
 SPECIALIZE(int)
 SPECIALIZE(uint)
+SPECIALIZE(short)
+SPECIALIZE(ushort)
 SPECIALIZE(uchar)
+SPECIALIZE(intl)
+SPECIALIZE(uintl)
 
 #undef SPECIALIZE
 
