@@ -34,7 +34,7 @@ namespace opencl
     Array<T> diagExtract(const Array<T> &in, const int num)
     {
         const dim_t *idims = in.dims().get();
-        dim_t size = std::max(idims[0], idims[1]) - std::abs(num);
+        dim_t size = std::min(idims[0], idims[1]) - std::abs(num);
         Array<T> out = createEmptyArray<T>(dim4(size, 1, idims[2], idims[3]));
 
         kernel::diagExtract<T>(out, in, num);
