@@ -18,5 +18,7 @@ INSTANTIATE(char  , true)
 INSTANTIATE(int   , true)
 INSTANTIATE(uint  , true)
 INSTANTIATE(uchar , true)
+INSTANTIATE(short , true)
+INSTANTIATE(ushort, true)
 
 }
