@@ -18,6 +18,10 @@ namespace opencl
     INSTANTIATE(af_mul_t, cdouble, cdouble)
     INSTANTIATE(af_mul_t, int    , int    )
     INSTANTIATE(af_mul_t, uint   , uint   )
+    INSTANTIATE(af_mul_t, intl   , intl   )
+    INSTANTIATE(af_mul_t, uintl  , uintl  )
     INSTANTIATE(af_mul_t, char   , int    )
     INSTANTIATE(af_mul_t, uchar  , uint   )
+    INSTANTIATE(af_mul_t, short  , int    )
+    INSTANTIATE(af_mul_t, ushort , uint   )
 }
