@@ -7,6 +7,7 @@
  * http://arrayfire.com/licenses/BSD-3-Clause
  ********************************************************/
 
+#pragma once
 #include <af/array.h>
 #include <Array.hpp>
 #include <ops.hpp>
@@ -14,8 +15,8 @@
 namespace opencl
 {
     template<af_op_t op, typename Ti, typename To>
-    Array<To> reduce(const Array<Ti> &in, const int dim);
+    Array<To> reduce(const Array<Ti> &in, const int dim, bool change_nan=false, double nanval=0);
 
     template<af_op_t op, typename Ti, typename To>
-    To reduce_all(const Array<Ti> &in);
+    To reduce_all(const Array<Ti> &in, bool change_nan=false, double nanval=0);
 }
