@@ -79,7 +79,7 @@ class ArrayAssign : public ::testing::Test
 };
 
 // create a list of types to be tested
-typedef ::testing::Types<float, af::cdouble, af::cfloat, double, int, uint, char, uchar, intl, uintl> TestTypes;
+typedef ::testing::Types<float, af::cdouble, af::cfloat, double, int, uint, char, uchar, intl, uintl, short, ushort> TestTypes;
 
 // register the type list
 TYPED_TEST_CASE(ArrayAssign, TestTypes);
@@ -771,8 +771,6 @@ TEST(ArrayAssign, CPP_ASSIGN_VECTOR_SEQ_2D)
     array a0 = a;
     array b = af::randu(len);
 
-    array idx = af::seq(st, en);
-
     a(af::seq(st, en)) = b;
 
     ASSERT_EQ(a.dims(0) , (dim_t)nx);
@@ -796,3 +794,194 @@ TEST(ArrayAssign, CPP_ASSIGN_VECTOR_SEQ_2D)
     delete[] h_a;
     delete[] h_b;
 }
+
+TEST(Assign, Copy)
+{
+    using af::array;
+
+    const int num = 20;
+    const int len = 10;
+    const int st = 3;
+    const int en = st + len - 1;
+
+    array a = af::randu(num, 1);
+    float *h_a0 = a.host<float>();
+
+    array b = af::randu(len);
+
+    float *d_ptr = a.device<float>();
+    af::copy(a, b, af::seq(st, en));
+
+    // Ensure that a still has same device pointer
+    ASSERT_EQ(d_ptr, a.device<float>());
+
+    float *h_a  =  a.host<float>();
+    float *h_b  =  b.host<float>();
+
+    for (int i = 0; i < num; i++) {
+        if (i >= st && i <= en) {
+            ASSERT_EQ(h_a[i], h_b[i - st]);
+        } else {
+            ASSERT_EQ(h_a[i], h_a0[i]);
+        }
+    }
+
+    delete[] h_a0;
+    delete[] h_a;
+    delete[] h_b;
+}
+
+TEST(Asssign, LinearCPP)
+{
+    using af::array;
+    const int nx = 5;
+    const int ny = 4;
+    const float val = 3;
+
+    const int st = nx - 2;
+    const int en = nx * (ny - 1);
+
+    array a = af::randu(nx, ny);
+    array a_copy = a;
+    af::index idx = af::seq(st, en);
+    a(idx) = 3;
+
+    ASSERT_EQ(a.dims(0), a_copy.dims(0));
+    ASSERT_EQ(a.dims(1), a_copy.dims(1));
+
+    std::vector<float> ha(nx * ny);
+    std::vector<float> ha_copy(nx * ny);
+
+    a.host(&ha[0]);
+    a_copy.host(&ha_copy[0]);
+
+    for (int i = 0; i < nx * ny; i++) {
+        if (i < st || i > en)
+            ASSERT_EQ(ha[i], ha_copy[i]) << "at " << i;
+        else
+            ASSERT_EQ(ha[i], val) << "at " << i;
+    }
+}
+
+TEST(Asssign, LinearAssignSeq)
+{
+    using af::array;
+    const int nx = 5;
+    const int ny = 4;
+    const float val = 3;
+    const array rhs = af::constant(val, 1, 1);
+
+    const int st = nx - 2;
+    const int en = nx * (ny - 1);
+
+    array a = af::randu(nx, ny);
+    af::index idx = af::seq(st, en);
+
+    af_array in_arr = a.get();
+    af_index_t ii = idx.get();
+    af_array rhs_arr = rhs.get();
+    af_array out_arr;
+
+    ASSERT_EQ(AF_SUCCESS,
+              af_assign_seq(&out_arr, in_arr, 1, &ii.idx.seq, rhs_arr));
+
+    af::array out(out_arr);
+
+    ASSERT_EQ(a.dims(0), out.dims(0));
+    ASSERT_EQ(a.dims(1), out.dims(1));
+
+    std::vector<float> hout(nx * ny);
+    std::vector<float> ha(nx * ny);
+
+    a.host(&ha[0]);
+    out.host(&hout[0]);
+
+    for (int i = 0; i < nx * ny; i++) {
+        if (i < st || i > en)
+            ASSERT_EQ(hout[i], ha[i]) << "at " << i;
+        else
+            ASSERT_EQ(hout[i], val) << "at " << i;
+    }
+}
+
+TEST(Asssign, LinearAssignGenSeq)
+{
+    using af::array;
+    const int nx = 5;
+    const int ny = 4;
+    const float val = 3;
+    const array rhs = af::constant(val, 1, 1);
+
+    const int st = nx - 2;
+    const int en = nx * (ny - 1);
+
+    array a = af::randu(nx, ny);
+    af::index idx = af::seq(st, en);
+
+    af_array in_arr = a.get();
+    af_index_t ii = idx.get();
+    af_array rhs_arr = rhs.get();
+    af_array out_arr;
+
+    ASSERT_EQ(AF_SUCCESS,
+              af_assign_gen(&out_arr, in_arr, 1, &ii, rhs_arr));
+
+    af::array out(out_arr);
+
+    ASSERT_EQ(a.dims(0), out.dims(0));
+    ASSERT_EQ(a.dims(1), out.dims(1));
+
+    std::vector<float> hout(nx * ny);
+    std::vector<float> ha(nx * ny);
+
+    a.host(&ha[0]);
+    out.host(&hout[0]);
+
+    for (int i = 0; i < nx * ny; i++) {
+        if (i < st || i > en)
+            ASSERT_EQ(hout[i], ha[i]) << "at " << i;
+        else
+            ASSERT_EQ(hout[i], val) << "at " << i;
+    }
+}
+
+TEST(Asssign, LinearAssignGenArr)
+{
+    using af::array;
+    const int nx = 5;
+    const int ny = 4;
+    const float val = 3;
+    const array rhs = af::constant(val, 1, 1);
+
+    const int st = nx - 2;
+    const int en = nx * (ny - 1);
+
+    array a = af::randu(nx, ny);
+    af::index idx = af::array(af::seq(st, en));
+
+    af_array in_arr = a.get();
+    af_index_t ii = idx.get();
+    af_array rhs_arr = rhs.get();
+    af_array out_arr;
+
+    ASSERT_EQ(AF_SUCCESS,
+              af_assign_gen(&out_arr, in_arr, 1, &ii, rhs_arr));
+
+    af::array out(out_arr);
+
+    ASSERT_EQ(a.dims(0), out.dims(0));
+    ASSERT_EQ(a.dims(1), out.dims(1));
+
+    std::vector<float> hout(nx * ny);
+    std::vector<float> ha(nx * ny);
+
+    a.host(&ha[0]);
+    out.host(&hout[0]);
+
+    for (int i = 0; i < nx * ny; i++) {
+        if (i < st || i > en)
+            ASSERT_EQ(hout[i], ha[i]) << "at " << i;
+        else
+            ASSERT_EQ(hout[i], val) << "at " << i;
+    }
+}
