@@ -19,7 +19,6 @@ TEST(MissingFunctionTests, Dummy)
 {
     array A = randu(10,10, f32);
     af_print(A);
-    af_print(rank(A));
     af_print(arg(A));
     af_print(arg(complex(A, A)));
     af_print(trunc(3 * A));
@@ -31,5 +30,4 @@ TEST(MissingFunctionTests, Dummy)
     af_print(minfilt(A, 3, 3) - erode(A, constant(1, 3,3)));
     af_print(maxfilt(A, 3, 3) - dilate(A, constant(1, 3,3)));
     printf("%lf\n", norm(A));
-    printf("%lf\n", det<double>(A));
 }
